searchData={"items":[{"type":"module","title":"Pigeon.LegacyFCM","doc":"`Pigeon.Adapter` for Legacy Firebase Cloud Messaging (FCM) push notifications.","ref":"Pigeon.LegacyFCM.html"},{"type":"module","title":"Getting Started - Pigeon.LegacyFCM","doc":"1. Create a `LegacyFCM` dispatcher.\n\n```\n# lib/legacy_fcm.ex\ndefmodule YourApp.LegacyFCM do\n  use Pigeon.Dispatcher, otp_app: :your_app\nend\n```\n\n2. (Optional) Add configuration to your `config.exs`.\n\n```\n# config.exs\n\nconfig :your_app, YourApp.LegacyFCM,\n  adapter: Pigeon.LegacyFCM,\n  key: \"your_fcm_key_here\"\n```\n\n3. Start your dispatcher on application boot.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      YourApp.LegacyFCM\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nIf you skipped step two, include your configuration.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      {YourApp.LegacyFCM, legacy_fcm_opts()}\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\n  defp legacy_fcm_opts do\n    [\n      adapter: Pigeon.LegacyFCM, \n      key: \"your_fcm_key_here\"\n    ]\n  end\nend\n```\n\n4. Create a notification.\n\n```\nmsg = %{\"body\" => \"your message\"}\nn = Pigeon.LegacyFCM.Notification.new(\"your device registration ID\", msg)\n```\n \n5. Send the notification. \n\nPushes are synchronous and return the notification with\nupdated `:status` and `:response` keys. If `:status` is success, `:response`\nwill contain a keyword list of individual registration ID responses.\n\n```\nYourApp.LegacyFCM.push(n)\n```","ref":"Pigeon.LegacyFCM.html#module-getting-started"},{"type":"module","title":"Sending to Multiple Registration IDs - Pigeon.LegacyFCM","doc":"Pass in a list of registration IDs, as many as you want.\n\n```\nmsg = %{\"body\" => \"your message\"}\nn = Pigeon.LegacyFCM.Notification.new([\"first ID\", \"second ID\"], msg)\n```","ref":"Pigeon.LegacyFCM.html#module-sending-to-multiple-registration-ids"},{"type":"module","title":"Notification Struct - Pigeon.LegacyFCM","doc":"```\n%Pigeon.LegacyFCM.Notification{\n  collapse_key: nil | String.t(),\n  dry_run: boolean,\n  message_id: nil | String.t(),\n  payload: %{...},\n  priority: :normal | :high,\n  registration_id: String.t() | [String.t(), ...],\n  response: [] | [{atom, String.t()}, ...], | atom,\n  restricted_package_name: nil | String.t(),\n  status: atom | nil,\n  time_to_live: non_neg_integer\n}\n```","ref":"Pigeon.LegacyFCM.html#module-notification-struct"},{"type":"module","title":"Notifications with Custom Data - Pigeon.LegacyFCM","doc":"FCM accepts both `notification` and `data` keys in its JSON payload. Set them like so:\n\n```\nnotification = %{\"body\" => \"your message\"}\ndata = %{\"key\" => \"value\"}\nPigeon.LegacyFCM.Notification.new(\"registration ID\", notification, data)\n```\n\nor\n\n```\nPigeon.LegacyFCM.Notification.new(\"registration ID\")\n|> put_notification(%{\"body\" => \"your message\"})\n|> put_data(%{\"key\" => \"value\"})\n```","ref":"Pigeon.LegacyFCM.html#module-notifications-with-custom-data"},{"type":"module","title":"Handling Push Responses - Pigeon.LegacyFCM","doc":"1. Pass an optional anonymous function as your second parameter.\n\n```\ndata = %{message: \"your message\"}\nn = Pigeon.LegacyFCM.Notification.new(data, \"device registration ID\")\nPigeon.FCM.push(n, fn(x) -> IO.inspect(x) end)\n{:ok, %Pigeon.LegacyFCM.Notification{...}}\n```\n\n2. Responses return the notification with an updated response.\n\n```\non_response = fn(n) ->\n  case n.status do\n    :success ->\n      bad_regids = LegacyFCM.Notification.remove?(n)\n      to_retry = LegacyFCM.Notification.retry?(n)\n      # Handle updated regids, remove bad ones, etc\n    :unauthorized ->\n      # Bad FCM key\n    error ->\n      # Some other error\n  end\nend\n\ndata = %{message: \"your message\"}\nn = Pigeon.LegacyFCM.Notification.new(\"your device token\", data)\nPigeon.FCM.push(n, on_response: on_response)\n```","ref":"Pigeon.LegacyFCM.html#module-handling-push-responses"},{"type":"module","title":"Error Responses - Pigeon.LegacyFCM","doc":"*Slightly modified from [FCM Server Reference](https://firebase.google.com/docs/cloud-messaging/http-server-ref#error-codes)*\n\n| Reason                           | Description                  |\n|----------------------------------|------------------------------|\n| `:missing_registration`          | Missing Registration Token   |\n| `:invalid_registration`          | Invalid Registration Token   |\n| `:not_registered`                | Unregistered Device          |\n| `:invalid_package_name`          | Invalid Package Name         |\n| `:authentication_error`          | Authentication Error         |\n| `:mismatch_sender_id`            | Mismatched Sender            |\n| `:invalid_json`                  | Invalid JSON                 |\n| `:message_too_big`               | Message Too Big              |\n| `:invalid_data_key`              | Invalid Data Key             |\n| `:invalid_ttl`                   | Invalid Time to Live         |\n| `:unavailable`                   | Timeout                      |\n| `:internal_server_error`         | Internal Server Error        |\n| `:device_message_rate_exceeded`  | Message Rate Exceeded        |\n| `:topics_message_rate_exceeded`  | Topics Message Rate Exceeded |\n| `:unknown_error`                 | Unknown Error                |","ref":"Pigeon.LegacyFCM.html#module-error-responses"},{"type":"module","title":"Pigeon.LegacyFCM.Notification","doc":"Defines `Pigeon.LegacyFCM.Notification` struct and convenience constructor functions.","ref":"Pigeon.LegacyFCM.Notification.html"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.new/3","doc":"Creates `LegacyFCM.Notification` struct with device registration IDs and optional\nnotification and data payloads.","ref":"Pigeon.LegacyFCM.Notification.html#new/3"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.new/3","doc":"iex> Pigeon.LegacyFCM.Notification.new(\"reg ID\")\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{},\n      registration_id: \"reg ID\",\n      priority: :normal\n    }\n\n    iex> Pigeon.LegacyFCM.Notification.new(\"reg ID\", %{\"body\" => \"test message\"})\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{\"notification\" => %{\"body\" => \"test message\"}},\n      registration_id: \"reg ID\",\n      priority: :normal\n    }\n\n    iex> Pigeon.LegacyFCM.Notification.new(\"reg ID\", %{\"body\" => \"test message\"},\n    ...> %{\"key\" => \"value\"})\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{\n        \"data\" => %{\"key\" => \"value\"},\n        \"notification\" => %{\"body\" => \"test message\"}\n      },\n      registration_id: \"reg ID\",\n      priority: :normal\n    }\n\n    iex> regids = Enum.map(0..1_499, fn(_x) -> \"reg ID\" end)\n    iex> [n1 | [n2]] = Pigeon.LegacyFCM.Notification.new(regids,\n    ...> %{\"body\" => \"test message\"}, %{\"key\" => \"value\"})\n    iex> Enum.count(n1.registration_id)\n    1000\n    iex> Enum.count(n2.registration_id)\n    500","ref":"Pigeon.LegacyFCM.Notification.html#new/3-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_collapse_key/2","doc":"Updates `\"collapse_key\"` key.","ref":"Pigeon.LegacyFCM.Notification.html#put_collapse_key/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_collapse_key/2","doc":"iex> put_collapse_key(%Pigeon.LegacyFCM.Notification{}, \"Updates available\")\n    %Pigeon.LegacyFCM.Notification{collapse_key: \"Updates available\"}","ref":"Pigeon.LegacyFCM.Notification.html#put_collapse_key/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_condition/2","doc":"Updates `\"condition\"` key.\n\nSupported condition: Topic, formatted as \"'yourTopic' in topics\". This value\nis case-insensitive.\n\nSupported operators: &&, ||. Maximum two operators per topic message supported.","ref":"Pigeon.LegacyFCM.Notification.html#put_condition/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_condition/2","doc":"iex> put_condition(%Pigeon.LegacyFCM.Notification{}, \"'test' in topics\")\n    %Pigeon.LegacyFCM.Notification{condition: \"'test' in topics\"}","ref":"Pigeon.LegacyFCM.Notification.html#put_condition/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_content_available/2","doc":"Updates `\"content_available\"` key.\n\nOn iOS, use this field to represent content-available in the APNs payload.\nWhen a notification or message is sent and this is set to true, an inactive\nclient app is awoken, and the message is sent through APNs as a silent\nnotification and not through the FCM connection server. Note that silent\nnotifications in APNs are not guaranteed to be delivered, and can depend on\nfactors such as the user turning on Low Power Mode, force quitting the app,\netc. On Android, data messages wake the app by default. On Chrome, currently\nnot supported.","ref":"Pigeon.LegacyFCM.Notification.html#put_content_available/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_content_available/2","doc":"iex> put_content_available(%Pigeon.LegacyFCM.Notification{}, true)\n    %Pigeon.LegacyFCM.Notification{content_available: true}","ref":"Pigeon.LegacyFCM.Notification.html#put_content_available/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_data/2","doc":"Updates `\"data\"` key in push payload.\n\nThis parameter specifies the custom key-value pairs of the message's payload.\n\nFor example, with data:{\"score\":\"3x1\"}:\n\nOn iOS, if the message is sent via APNs, it represents the custom data fields.\nIf it is sent via FCM connection server, it would be represented as key value\ndictionary in AppDelegate application:didReceiveRemoteNotification:.\n\nOn Android, this would result in an intent extra named score with the string\nvalue 3x1.\n\nThe key should not be a reserved word (\"from\" or any word starting with\n\"google\" or \"gcm\"). Do not use any of the words defined in this table\n(such as collapse_key).\n\nValues in string types are recommended. You have to convert values in objects\nor other non-string data types (e.g., integers or booleans) to string.","ref":"Pigeon.LegacyFCM.Notification.html#put_data/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_data/2","doc":"iex> put_data(%Pigeon.LegacyFCM.Notification{}, %{\"key\" => 1234})\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{\"data\" => %{\"key\" => 1234}},\n      registration_id: nil\n    }","ref":"Pigeon.LegacyFCM.Notification.html#put_data/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_dry_run/1","doc":"Sets `\"dry_run\"` key to true.\n\nThis parameter, when set to true, allows developers to test a request without\nactually sending a message.\n\nThe default value is false.","ref":"Pigeon.LegacyFCM.Notification.html#put_dry_run/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_dry_run/1","doc":"iex> put_dry_run(%Pigeon.LegacyFCM.Notification{})\n    %Pigeon.LegacyFCM.Notification{dry_run: true}","ref":"Pigeon.LegacyFCM.Notification.html#put_dry_run/1-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_mutable_content/2","doc":"Updates `\"mutable_content\"` key.\n\nCurrently for iOS 10+ devices only. On iOS, use this field to represent\nmutable-content in the APNs payload. When a notification is sent and this is\nset to true, the content of the notification can be modified before it is\ndisplayed, using a Notification Service app extension. This parameter will be\nignored for Android and web.","ref":"Pigeon.LegacyFCM.Notification.html#put_mutable_content/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_mutable_content/2","doc":"iex> put_mutable_content(%Pigeon.LegacyFCM.Notification{}, true)\n    %Pigeon.LegacyFCM.Notification{mutable_content: true}","ref":"Pigeon.LegacyFCM.Notification.html#put_mutable_content/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_notification/2","doc":"Updates `\"notification\"` key in push payload.\n\nThis parameter specifies the predefined, user-visible key-value pairs of the\nnotification payload. See Notification payload support for detail. For more\ninformation about notification message and data message options, see\n[Message types](https://firebase.google.com/docs/cloud-messaging/concept-options#notifications_and_data_messages).\nIf a notification payload is provided, or the content_available option is set\nto true for a message to an iOS device, the message is sent through APNs,\notherwise it is sent through the FCM connection server.","ref":"Pigeon.LegacyFCM.Notification.html#put_notification/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_notification/2","doc":"iex> put_notification(%Pigeon.LegacyFCM.Notification{},\n    ...> %{\"body\" => \"message\"})\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{\"notification\" => %{\"body\" => \"message\"}},\n      registration_id: nil\n    }","ref":"Pigeon.LegacyFCM.Notification.html#put_notification/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_priority/2","doc":"Updates `\"priority\"` key.\n\nSets the priority of the message. Valid values are \"normal\" and \"high.\" On\niOS, these correspond to APNs priorities 5 and 10.\n\nBy default, notification messages are sent with high priority, and data\nmessages are sent with normal priority. Normal priority optimizes the client\napp's battery consumption and should be used unless immediate delivery is\nrequired. For messages with normal priority, the app may receive the message\nwith unspecified delay.\n\nWhen a message is sent with high priority, it is sent immediately, and the app\ncan display a notification.","ref":"Pigeon.LegacyFCM.Notification.html#put_priority/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_priority/2","doc":"iex> put_priority(%Pigeon.LegacyFCM.Notification{}, :normal)\n    %Pigeon.LegacyFCM.Notification{priority: :normal}\n\n    iex> put_priority(%Pigeon.LegacyFCM.Notification{}, :high)\n    %Pigeon.LegacyFCM.Notification{priority: :high}\n\n    iex> put_priority(%Pigeon.LegacyFCM.Notification{priority: :normal}, :bad)\n    %Pigeon.LegacyFCM.Notification{priority: :normal}","ref":"Pigeon.LegacyFCM.Notification.html#put_priority/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_restricted_package_name/2","doc":"Updates `\"restricted_package_name\"` key.\n\nThis parameter specifies the package name of the application where the\nregistration tokens must match in order to receive the message. (Only affects android)","ref":"Pigeon.LegacyFCM.Notification.html#put_restricted_package_name/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_restricted_package_name/2","doc":"iex> put_restricted_package_name(%Pigeon.LegacyFCM.Notification{}, \"com.example.app\")\n    %Pigeon.LegacyFCM.Notification{restricted_package_name: \"com.example.app\"}","ref":"Pigeon.LegacyFCM.Notification.html#put_restricted_package_name/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_time_to_live/2","doc":"Updates `\"time_to_live\"` key.\n\nThis parameter specifies how long (in seconds) the message should be kept in\nFCM storage if the device is offline. The maximum time to live supported is 4\nweeks, and the default value is 4 weeks. For more information, see\n[Setting the lifespan of a message](https://firebase.google.com/docs/cloud-messaging/concept-options#ttl).","ref":"Pigeon.LegacyFCM.Notification.html#put_time_to_live/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_time_to_live/2","doc":"iex> put_time_to_live(%Pigeon.LegacyFCM.Notification{}, 60 * 60 * 24)\n    %Pigeon.LegacyFCM.Notification{time_to_live: 86_400}","ref":"Pigeon.LegacyFCM.Notification.html#put_time_to_live/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.remove?/1","doc":"Returns a list of registration IDs that should be removed","ref":"Pigeon.LegacyFCM.Notification.html#remove?/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.remove?/1","doc":"iex> n = %Pigeon.LegacyFCM.Notification{response: [\n    ...> {:success, \"regid1\"}, {:invalid_registration, \"regid2\"},\n    ...> {:success, \"regid3\"}, {:update, {\"regid4\", \"new_regid4\"}},\n    ...> {:not_registered, \"regid5\"}, {:unavailable, \"regid6\"}]}\n    iex> remove?(n)\n    [\"regid2\", \"regid5\"]","ref":"Pigeon.LegacyFCM.Notification.html#remove?/1-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.retry?/1","doc":"Returns a list of registration IDs that should be retried","ref":"Pigeon.LegacyFCM.Notification.html#retry?/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.retry?/1","doc":"iex> n = %Pigeon.LegacyFCM.Notification{response: [\n    ...> {:success, \"regid1\"}, {:invalid_registration, \"regid2\"},\n    ...> {:success, \"regid3\"}, {:update, {\"regid4\", \"new_regid4\"}},\n    ...> {:not_registered, \"regid5\"}, {:unavailable, \"regid6\"}]}\n    iex> retry?(n)\n    [\"regid6\"]","ref":"Pigeon.LegacyFCM.Notification.html#retry?/1-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.success?/1","doc":"Returns a list of successful registration IDs","ref":"Pigeon.LegacyFCM.Notification.html#success?/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.success?/1","doc":"iex> n = %Pigeon.LegacyFCM.Notification{response: [\n    ...> {:success, \"regid1\"}, {:invalid_registration, \"regid2\"},\n    ...> {:success, \"regid3\"}, {:update, {\"regid4\", \"new_regid4\"}},\n    ...> {:not_registered, \"regid5\"}, {:unavailable, \"regid6\"}]}\n    iex> success?(n)\n    [\"regid1\", \"regid3\"]","ref":"Pigeon.LegacyFCM.Notification.html#success?/1-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.update?/1","doc":"Returns a list of registration IDs and their corresponding new ID","ref":"Pigeon.LegacyFCM.Notification.html#update?/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.update?/1","doc":"iex> n = %Pigeon.LegacyFCM.Notification{response: [\n    ...> {:success, \"regid1\"}, {:invalid_registration, \"regid2\"},\n    ...> {:success, \"regid3\"}, {:update, {\"regid4\", \"new_regid4\"}},\n    ...> {:not_registered, \"regid5\"}, {:unavailable, \"regid6\"}]}\n    iex> update?(n)\n    [{\"regid4\", \"new_regid4\"}]","ref":"Pigeon.LegacyFCM.Notification.html#update?/1-examples"},{"type":"type","title":"Pigeon.LegacyFCM.Notification.regid_error_response/0","doc":"","ref":"Pigeon.LegacyFCM.Notification.html#t:regid_error_response/0"},{"type":"type","title":"Pigeon.LegacyFCM.Notification.regid_response/0","doc":"LegacyFCM push response for individual registration IDs\n\n- `{:success, \"reg_id\"}` - Push was successfully sent\n- `{:update, {\"reg_id\", \"new_reg_id\"}}` - Push successful but user should\n  use new registration ID for future pushes\n- `{regid_error_response, \"reg_id\"}` - Push attempted but server responded\n  with error","ref":"Pigeon.LegacyFCM.Notification.html#t:regid_response/0"},{"type":"type","title":"Pigeon.LegacyFCM.Notification.status/0","doc":"Status of LegacyFCM request\n\n- `:success` - Notification was processed successfully\n- `:timeout` - Worker did not respond within timeout. This is likely an\n   internal error\n- `:unauthorized` - Bad LegacyFCM key\n- `:malformed_json` - Push payload was invalid JSON\n- `:internal_server_error` - LegacyFCM server encountered an error while trying\n   to process the request\n- `:unavailable` - LegacyFCM server couldn't process the request in time","ref":"Pigeon.LegacyFCM.Notification.html#t:status/0"},{"type":"type","title":"Pigeon.LegacyFCM.Notification.t/0","doc":"","ref":"Pigeon.LegacyFCM.Notification.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v0.2.0 - 2024-12-09 - Changelog","doc":"","ref":"changelog.html#v0-2-0-2024-12-09"},{"type":"extras","title":"Changed - Changelog","doc":"- Pigeon dependency requirement updated to `~> 2.0`.\n\nInitial release.","ref":"changelog.html#changed"},{"type":"extras","title":"v0.1.0 - 2024-09-10 - Changelog","doc":"Initial release.","ref":"changelog.html#v0-1-0-2024-09-10"},{"type":"extras","title":"License","doc":"Copyright (c) 2024 Codedge LLC (https://www.codedge.io/)\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in\nall copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\nTHE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}